@@ -5,7 +5,7 @@
 #' 
 #' @param net An igraph object representing a network
 #' 
-#' @author Phil Boileau , \email{philippe.boileau@mail.concordia.ca}
+#' @author Philippe Boileau, \email{philippe_boileau@@berkeley.edu}
 #' 
 #' @importFrom igraph constraint vcount ecount
 hierarchy <- function(net){
@@ -13,12 +13,12 @@ hierarchy <- function(net){
   # get the constraints of the network, their sum and the number of nodes
   cons <- constraint(net)
   cons[is.nan(cons)] <- 0
-  sumCons <- sum(cons)
+  sum_cons <- sum(cons)
   neigh <- vcount(net)
   
   # calculate the vectors needed to perform the calculation
-  v1 <- cons / (sumCons / neigh)
-  v2 <- log(cons/ (sumCons / neigh))
+  v1 <- cons / (sum_cons / neigh)
+  v2 <- log(cons/ (sum_cons / neigh))
   v2[is.infinite(v2)] <- 0
   h <- sum(v1 * v2) / (neigh * log(neigh))
   
